@@ -135,11 +135,18 @@ def get_install_options():
     add provider in front of the provider specific options to prevent overlap"""
     install_options = general_install_options
 
-    for name in genomepy.ProviderBase.list_providers():
-        p_dict = genomepy.ProviderBase.create(name).list_install_options()
-        for option in p_dict.keys():
-            p_dict[option]["long"] = name + "-" + p_dict[option]["long"]
-        install_options.update(p_dict)
+    # only run if -h or --help are in the arguments
+    if "-h" in click.get_os_args() or "--help" in click.get_os_args():
+        for name in genomepy.ProviderBase.list_providers():
+            # directly access the provider's arguments, skips __init__
+            p_dict = eval(
+                "genomepy.provider."
+                + name.capitalize()
+                + "Provider.list_install_options(None)"
+            )
+            for option in p_dict.keys():
+                p_dict[option]["long"] = name + "-" + p_dict[option]["long"]
+            install_options.update(p_dict)
 
     return install_options
 
